==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_fields/INSPECTIONPOINTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour INSPECTIONPOINTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="INSPECTIONPOINTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INSPECTIONOBJECTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OBJTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}POINTTYPEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}POINTCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INSPECTIONPOINTID_Type", propOrder = {
    "inspectionobjectid",
    "objtype",
    "pointtypeid",
    "pointcode",
    "description"
})
public class INSPECTIONPOINTID_Type {

    @XmlElement(name = "INSPECTIONOBJECTID", required = true)
    protected OBJECT_Type inspectionobjectid;
    @XmlElement(name = "OBJTYPE", required = true)
    protected String objtype;
    @XmlElement(name = "POINTTYPEID", required = true)
    protected POINTTYPEID_Type pointtypeid;
    @XmlElement(name = "POINTCODE", required = true)
    protected String pointcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété inspectionobjectid.
     * 
     * @return
     *     possible object is
     *     {@link OBJECT_Type }
     *     
     */
    public OBJECT_Type getINSPECTIONOBJECTID() {
        return inspectionobjectid;
    }

    /**
     * Définit la valeur de la propriété inspectionobjectid.
     * 
     * @param value
     *     allowed object is
     *     {@link OBJECT_Type }
     *     
     */
    public void setINSPECTIONOBJECTID(OBJECT_Type value) {
        this.inspectionobjectid = value;
    }

    /**
     * Obtient la valeur de la propriété objtype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOBJTYPE() {
        return objtype;
    }

    /**
     * Définit la valeur de la propriété objtype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOBJTYPE(String value) {
        this.objtype = value;
    }

    /**
     * Obtient la valeur de la propriété pointtypeid.
     * 
     * @return
     *     possible object is
     *     {@link POINTTYPEID_Type }
     *     
     */
    public POINTTYPEID_Type getPOINTTYPEID() {
        return pointtypeid;
    }

    /**
     * Définit la valeur de la propriété pointtypeid.
     * 
     * @param value
     *     allowed object is
     *     {@link POINTTYPEID_Type }
     *     
     */
    public void setPOINTTYPEID(POINTTYPEID_Type value) {
        this.pointtypeid = value;
    }

    /**
     * Obtient la valeur de la propriété pointcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPOINTCODE() {
        return pointcode;
    }

    /**
     * Définit la valeur de la propriété pointcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPOINTCODE(String value) {
        this.pointcode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/INSPECTIONPOINTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for INSPECTIONPOINTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="INSPECTIONPOINTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INSPECTIONOBJECTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OBJTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}POINTTYPEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}POINTCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INSPECTIONPOINTID_Type", propOrder = {
    "inspectionobjectid",
    "objtype",
    "pointtypeid",
    "pointcode",
    "description"
})
public class INSPECTIONPOINTID_Type {

    @XmlElement(name = "INSPECTIONOBJECTID", required = true)
    protected OBJECT_Type inspectionobjectid;
    @XmlElement(name = "OBJTYPE", required = true)
    protected String objtype;
    @XmlElement(name = "POINTTYPEID", required = true)
    protected POINTTYPEID_Type pointtypeid;
    @XmlElement(name = "POINTCODE", required = true)
    protected String pointcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the inspectionobjectid property.
     * 
     * @return
     *     possible object is
     *     {@link OBJECT_Type }
     *     
     */
    public OBJECT_Type getINSPECTIONOBJECTID() {
        return inspectionobjectid;
    }

    /**
     * Sets the value of the inspectionobjectid property.
     * 
     * @param value
     *     allowed object is
     *     {@link OBJECT_Type }
     *     
     */
    public void setINSPECTIONOBJECTID(OBJECT_Type value) {
        this.inspectionobjectid = value;
    }

    /**
     * Gets the value of the objtype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOBJTYPE() {
        return objtype;
    }

    /**
     * Sets the value of the objtype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOBJTYPE(String value) {
        this.objtype = value;
    }

    /**
     * Gets the value of the pointtypeid property.
     * 
     * @return
     *     possible object is
     *     {@link POINTTYPEID_Type }
     *     
     */
    public POINTTYPEID_Type getPOINTTYPEID() {
        return pointtypeid;
    }

    /**
     * Sets the value of the pointtypeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link POINTTYPEID_Type }
     *     
     */
    public void setPOINTTYPEID(POINTTYPEID_Type value) {
        this.pointtypeid = value;
    }

    /**
     * Gets the value of the pointcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPOINTCODE() {
        return pointcode;
    }

    /**
     * Sets the value of the pointcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPOINTCODE(String value) {
        this.pointcode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
